@@ -3,7 +3,6 @@ from sqlalchemy.orm.exc import NoResultFound
 from wtforms import ValidationError, fields, validators
 from wtforms.ext.sqlalchemy.orm import converts, ModelConverter
 from wtforms.ext.sqlalchemy.fields import QuerySelectField, QuerySelectMultipleField
-from wtforms.ext.sqlalchemy.orm import model_form
 
 from flask.ext.superadmin import form
 
@@ -60,10 +59,8 @@ class AdminModelConverter(ModelConverter):
         return None
 
     def _get_field_override(self, name):
-        # if self.view.form_overrides:
-        #     return self.view.form_overrides.get(name)
-
-        return None
+        if self.view.field_overrides:
+            return self.view.field_overrides.get(name)
 
     def convert(self, model, mapper, prop, field_args, *args):
         kwargs = {
@@ -85,7 +82,7 @@ class AdminModelConverter(ModelConverter):
             })
             if local_column.nullable:
                 kwargs['validators'].append(validators.Optional())
-            elif prop.direction.name not in ('MANYTOMANY','ONETOMANY'):
+            elif prop.direction.name not in ('MANYTOMANY', 'ONETOMANY'):
                 kwargs['validators'].append(validators.Required())
 
             # Override field type if necessary
